

class ClassA(object):
    def __init__(self):
        self.x = "D"

class ClassB(object):
    def __init__(self):
        self.x = "E"

class ClassC(object):
    def __init__(self):
        self.x = "F"


